/**
  *  \file client/tiles/basetech.cc
  *
  *  (c) 2001-2016 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/basetech.h"
#include "util/nls.h"
#include "util/misc.h"
#include "game/planet.h"
#include "ui/widgets/button.h"
#include "ui/uiglobal.h"

static void
drawBaseTechTile(UIAbstractTableWriter& tw, GPlanet* p, bool narrow)
{
    if (!p || !p->hasFullBaseData())
        return;

    enum { N = 4 };
    static const char*const tlnames[][N] = {
        { N_("Engines:"),     N_("Hulls:"),     N_("Beam Weapons:"), N_("Torpedoes:") },
        { N_("Engine tech:"), N_("Hull tech:"), N_("Beam tech:"),    N_("Torp tech:") },
    };

    tw.newLColumn();
    for (int i = 0; i < N; ++i)
        tw.writeFixedCell(UIColor::tc_Static, _(tlnames[narrow][i]));

    tw.newRColumn(fonts[FONT_NORMAL]->getTextWidth("99"));
    tw.writeVariableCell(UIColor::tc_Green, itoa(p->getBaseTechLevel(tl_Engine)));
    tw.writeVariableCell(UIColor::tc_Green, itoa(p->getBaseTechLevel(tl_Hull)));
    tw.writeVariableCell(UIColor::tc_Green, itoa(p->getBaseTechLevel(tl_Beam)));
    tw.writeVariableCell(UIColor::tc_Green, itoa(p->getBaseTechLevel(tl_Torpedo)));

    tw.newLColumn(5);

    tw.newLColumn();
    tw.writeFixedCell(UIColor::tc_Static, _("Defense:"));
    tw.writeFixedCell(UIColor::tc_Static, _("Fighters:"));
    tw.writeFixedCell(UIColor::tc_Static, _("Damage:"));
    tw.writeFixedCell(UIColor::tc_Static, string_t());

    tw.newRColumn(fonts[FONT_NORMAL]->getTextWidth(_("none")));

    tw.writeVariableCell(UIColor::tc_Green, numToString(p->getStructures(str_BaseDefense)));
    tw.writeVariableCell(UIColor::tc_Green, numToString(p->getCargo(el_Fighters)));
    if (p->getBaseDamage()) {
        tw.writeVariableCell(UIColor::tc_Red, itoa(p->getBaseDamage()) + "%");
    } else {
        tw.writeVariableCell(UIColor::tc_Green, _("none"));
    }
    tw.writeVariableCell(UIColor::tc_Static, string_t());

    tw.finish();
}

/***************************** WBaseTechTile *****************************/

WBaseTechTile::WBaseTechTile(GObjectSelection& selection)
    : WObjectSelectionObserverTile(GfxPoint(315, 4 * font_heights[FONT_NORMAL]), selection)
{
    setLayout(RightJustified, 0, false);
    addControl(GfxRect(0,  0, 20, 20), h.add(new UIButton("T", 't')));
    addControl(GfxRect(0, 25, 20, 20), h.add(new UIButton("D", 'd')));
    addControl(GfxRect(0, 50, 20, 20), h.add(new UIButton("S", 's')));
}

void
WBaseTechTile::drawData(GfxCanvas& can)
{
    GfxContext ctx;
    ctx.useCanvas(can).useColorScheme(getSkin());
    UITableWriter tw(ctx, getInnerSize(5, 0), FONT_NORMAL);
    GPlanet* p = dynamic_cast<GPlanet*>(getCurrentObject());
    drawBaseTechTile(tw, p, false);
}



WNarrowBaseTechTile::WNarrowBaseTechTile(GObjectSelection& selection)
    : WObjectSelectionObserverTile(GfxPoint(250, font_heights[FONT_NORMAL]*4), selection)
{ }

void
WNarrowBaseTechTile::drawData(GfxCanvas& can)
{
    GfxContext ctx;
    ctx.useCanvas(can).useColorScheme(getSkin());
    UITableWriter tw(ctx, getInnerSize(0, 0), FONT_NORMAL);
    GPlanet* p = dynamic_cast<GPlanet*>(getCurrentObject());
    drawBaseTechTile(tw, p, true);
}
