/**
  *  \file int/autotask.h
  *  \brief Interpreter: Editing of Auto Tasks
  *
  *  (c) 2001-2016 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_AUTOTASK_H
#define PCC_V2_INT_AUTOTASK_H

#include <vector>
#include "cpluslib/string.h"
#include "cpluslib/types.h"

class IntExecutionContext;

/** Auto Task editor. Converts a process (IntExecutionContext) into an
    editable string list, and that back into a process. */
class IntAutoTaskEditor {
 public:
    IntAutoTaskEditor();
    ~IntAutoTaskEditor();

    bool loadFromProcess(IntExecutionContext& exc);
    void saveToProcess(IntExecutionContext& exc);
    void clear();

    uint32_t getNumInstructions() const;
    uint32_t getPC() const;
    bool     isInSubroutineCall() const;
    const string_t& operator[](uint32_t index) const;

    void replace(uint32_t pos, uint32_t nold, const string_t& line);
    void replace(uint32_t pos, uint32_t nold, const string_t* line, uint32_t nnew);
    void setPC(uint32_t newPC);

    static bool isValidCommand(const string_t& cmd);
    static bool isRestartCommand(const string_t& cmd);
    static bool isBlankCommand(const string_t& cmd);

 private:
    // Auto task code.
    std::vector<string_t> code;

    // Current position. pc is the perceived program counter, pc_rel
    // is an (opaque) identifier for the relative position of the
    // program after pc. 0 means we're sitting exactly at pc, >0 means
    // we're inside the command.
    uint32_t pc;
    uint32_t pc_rel;

    void checkSetPC(IntExecutionContext& exc, uint32_t raw_pc, uint32_t length);
};



inline uint32_t
IntAutoTaskEditor::getNumInstructions() const
{
    return code.size();
}

inline uint32_t
IntAutoTaskEditor::getPC() const
{
    return pc;
}

inline bool
IntAutoTaskEditor::isInSubroutineCall() const
{
    return pc_rel != 0;
}

inline const string_t&
IntAutoTaskEditor::operator[](uint32_t index) const
{
    return code[index];
}

#endif
