/**
  *  \file ui/widgets/minimalbutton.cc
  *  \brief UIMinimalButton widget
  *
  *  (c) 2001-2016 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/widgets/minimalbutton.h"
#include "gfx/gfxcontext.h"
#include "gfx/palette.h"
#include "ui/skin.h"
#include "ui/uiglobal.h"

/** Constructor.
    \param id Widget Id
    \param name Name of button
    \param key Hotkey
    \param layout Make this button layoutable (default: no layout, user must manually place it) */
UIMinimalButton::UIMinimalButton(int id, string_t name, UIKey key, bool layout)
    : UIAbstractButton(id, key), name(name), layout(layout)
{ }

void
UIMinimalButton::drawContent(GfxCanvas& can)
{
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_NORMAL]);
#if 1
    /* Simple */
    ctx.setSolidBackground();
    if (hasState(st_Selected))
        ctx.setColor(UIColor::tc_White);
    else
        ctx.setColor(UIColor::tc_Static);
#else
    /* A little nicer, but currently totally alien */
    drawBackground(ctx, extent);
    ctx.useColorScheme(GfxStandardColorScheme::instance);
    if (hasState(st_Selected)) {
        if (ui_screen_bits > 8) {
            ctx.setColor(COLOR_SHIELD+8);
            ctx.setAlpha(64);
        } else {
            ctx.setColor(COLOR_SHIELD+5);
        }
        outTextF(ctx, extent.x, extent.y, extent.w, name);
        outTextF(ctx, extent.x+4, extent.y, extent.w-4, name);
        outTextF(ctx, extent.x+2, extent.y-1, extent.w-2, name);
        outTextF(ctx, extent.x+2, extent.y+1, extent.w-2, name);
        ctx.setAlpha(GFX_ALPHA_OPAQUE);
        ctx.setColor(COLOR_WHITE);
    } else {
        ctx.setColor(COLOR_GRAY);
    }
#endif
    outTextF(ctx, extent.x+2, extent.y, extent.w-2, name);
    can.update(getExtent());
}

void
UIMinimalButton::getLayoutInfo(LayoutInfo& li)
{
    /* This always returns a size, even when in NoLayout mode,
       to give users a hint how to place us. */
    li.flags = layout ? li_FlexibleH : li_NoLayout;
    li.min_size = li.pref_size = GfxPoint(fonts[FONT_NORMAL]->getTextWidth(name), font_heights[FONT_NORMAL]).movedBy(4,2);
}
