/**
  *  \file ui/widgets/radiobutton.cc
  *  \brief UIRadioButton widget
  *
  *  (c) 2001-2016 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/widgets/radiobutton.h"
#include "resmgr/resmgr.h"

/** Create radio button.
    \param id      widget id
    \param name    text
    \param key     hotkey
    \param valuep  pointer to value object for this radio group
    \param myvalue the value of this radio button */
UIRadioButton::UIRadioButton(int id, string_t name, UIKey key, Value& valuep, int myvalue)
    : UIAbstractCheckbox(id, name, key),
      value(valuep), myvalue(myvalue),
      conn(observe(valuep.sig_changed))
{ }

UIRadioButton::~UIRadioButton()
{ }

void
UIRadioButton::click(int)
{
    setValue(myvalue);
    setFocusedWidget();
}

Ptr<GfxPixmap>
UIRadioButton::getPixmap()
{
    if (getValue() == myvalue)
        return requestPixmap(ResId("radio", 2));
    else
        return requestPixmap(ResId("radio", 1));
}
